pdf(file="Figure_3_single_components_XRPD.pdf", 8.3*0.8*2, 11.7*0.8)

read_and_scale <- function(filename, xmin=5, xmax=40)
{
        tempdata <- read.csv(file=filename,  sep=" ", header=FALSE)
        tempdata <- subset(tempdata, tempdata[,1] >= xmin & tempdata[,1] <= xmax)
        tempdata[,2] <- scale(tempdata[,2])
        return(tempdata)
}


# Read in data
unmilled_T <- read_and_scale("Data/Individual/Terephthalic acid/Unmilled terephthalic acid.xy")
t_zero_T <- read_and_scale("Data/Individual/Terephthalic acid/Terephthathalic acid CM _zero weeks.xy")
t_three_weeks_T <- read_and_scale("Data/Individual/Terephthalic acid/Terephthalic acid CM_week 3.xy")
unmilled_I <- read_and_scale("Data/Individual/Isophthalic acid/Unmilled isophthalic acid.xy")
t_zero_I <- read_and_scale("Data/Individual/Isophthalic acid/Isophthalic acid CM_zero weeks.xy")
t_three_weeks_I <- read_and_scale("Data/Individual/Isophthalic acid/Isophthalic acid CM_week 3.xy")
unmilled_P <- read_and_scale("Data/Individual/Phthalic acid/Unmilled phthalic acid.xy")
t_zero_P <- read_and_scale("Data/Individual/Phthalic acid/Phthalic acid CM_zero weeks.xy")
t_three_weeks_P <- read_and_scale("Data/Individual/Phthalic acid/Phthalic acid CM_week 3.xy")


#####################################################
# referee request to subtract brass background peaks
######################################################

brass <- read_and_scale("Brass background.xy")
names(brass) <- c("Angle", "Intensity")
# identify brass peaks
# first peak
first_peak_min <- 31.1
first_peak_max <- 31.6
peak_position_estimate <- 31.35
peak_width_estimate <- 0.1
peak_intensity_estimate <- 15
background_estimate <- 0
fit1 <- nls( Intensity ~ peak_intensity*exp(-1/2*(Angle-peak_position)^2/peak_width^2) + background, start=c(peak_position=peak_position_estimate, peak_width=peak_width_estimate, peak_intensity=peak_intensity_estimate, background=background_estimate), data = subset(brass, brass$Angle >= first_peak_min & brass$Angle <= first_peak_max))
#plot(brass, xlim=c(first_peak_min, first_peak_max), type="l")
#lines(subset(brass, brass$Angle >= first_peak_min & brass$Angle <= first_peak_max)$Angle, predict(fit1), col="red")

# second peak
second_peak_min <- 36.1
second_peak_max <- 36.6
peak_position_estimate <- 36.35
peak_intensity_estimate <- 5
fit2 <- nls( Intensity ~ peak_intensity*exp(-1/2*(Angle-peak_position)^2/peak_width^2) + background, start=c(peak_position=peak_position_estimate, peak_width=peak_width_estimate, peak_intensity=peak_intensity_estimate, background=background_estimate), data = subset(brass, brass$Angle >= second_peak_min & brass$Angle <= second_peak_max))
#plot(brass, xlim=c(second_peak_min, second_peak_max), type="l")
#lines(subset(brass, brass$Angle >= second_peak_min & brass$Angle <= second_peak_max)$Angle, predict(fit2), col="red")
peak_ratio_for_brass <- coef(fit1)[3] / coef(fit2)[3]
x <- unmilled_T[,1]
y <- coef(fit1)[3] * exp(-1/2*(x - as.numeric(coef(fit1)[1]))^2/as.numeric(coef(fit1)[2])^2) + coef(fit2)[3] * exp(-1/2*(x - as.numeric(coef(fit2)[1]))^2/as.numeric(coef(fit2)[2])^2) # Two calculated Gaussians using the fits to the brass trace above.
calculated_brass_trace <- cbind(x,y)

# Subtract a calculated brass trace from the data, scaled by the intensity of the first peak in the real pattern divided by intensity of the calculated brass trace
# As per referee comments
subtract_brass_peaks <- function(datafile)
{
        names(datafile) <- c("Angle", "Intensity")
        temp_fit <- nls(Intensity ~ peak_intensity*exp(-1/2*(Angle-peak_position)^2/peak_width^2) + background, start=c(peak_position=as.numeric(coef(fit1)[1]), peak_width=as.numeric(coef(fit1)[2]), peak_intensity=as.numeric(coef(fit1)[3]), background=as.numeric(coef(fit1)[4])), data = subset(datafile, datafile[,1] >= first_peak_min & datafile[,1] <= first_peak_max))
        myoutput <- datafile
        myoutput[,2] <- datafile[,2] - calculated_brass_trace[,2]*as.numeric(coef(temp_fit)[3])/as.numeric(coef(fit1)[3])
        return(myoutput)
}

# Read in data again, this time subtracting brass peaks.
unmilled_T <- subtract_brass_peaks(read_and_scale("Data/Individual/Terephthalic acid/Unmilled terephthalic acid.xy"))
t_zero_T <- subtract_brass_peaks(read_and_scale("Data/Individual/Terephthalic acid/Terephthathalic acid CM _zero weeks.xy"))
t_three_weeks_T <- subtract_brass_peaks(read_and_scale("Data/Individual/Terephthalic acid/Terephthalic acid CM_week 3.xy"))
unmilled_I <- subtract_brass_peaks(read_and_scale("Data/Individual/Isophthalic acid/Unmilled isophthalic acid.xy"))
t_zero_I <- subtract_brass_peaks(read_and_scale("Data/Individual/Isophthalic acid/Isophthalic acid CM_zero weeks.xy"))
t_three_weeks_I <- subtract_brass_peaks(read_and_scale("Data/Individual/Isophthalic acid/Isophthalic acid CM_week 3.xy"))
unmilled_P <- subtract_brass_peaks(read_and_scale("Data/Individual/Phthalic acid/Unmilled phthalic acid.xy"))
t_zero_P <- subtract_brass_peaks(read_and_scale("Data/Individual/Phthalic acid/Phthalic acid CM_zero weeks.xy"))
#t_three_weeks_P <- subtract_brass_peaks(read_and_scale("Data/Individual/Phthalic acid/Phthalic acid CM_week 3.xy")) # no detectable brass peaks so no subtraction done



###################################


### Plot main figure - SINGLE components ###

#Terephthalic acid
par(fig = c(0,1/3,0,1))
offset <- 13
plot(unmilled_T[,1], scale(unmilled_T[,2]), type="l", ylim=c(-1, 34), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="a) Terephthalic acid")
text(2, -1, "As received", adj = c(0, NA))
lines(t_zero_T[,1], scale(t_zero_T[,2])+offset)
text(2, 11.5, "Cryomilled: t=0", adj = c(0, NA))
lines(t_three_weeks_T[,1], scale(t_three_weeks_T[,2])+offset*2*0.9)
text(2, 22, "Cryomilled: t=three weeks", adj = c(0, NA))

# Isophthalic acid
par(fig = c(1/3,2/3,0,1), new = T)
offset <- 13
plot(unmilled_I[,1], scale(unmilled_I[,2]), type="l", ylim=c(-1, 34), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="b) Isophthalic acid")
text(2, -1, "As received", adj = c(0, NA))
lines(t_zero_I[,1], scale(t_zero_I[,2])+offset)
text(2, 11.5, "Cryomilled: t=0", adj = c(0, NA))
lines(t_three_weeks_I[,1], scale(t_three_weeks_I[,2])+offset*2*0.9)
text(2, 22, "Cryomilled: t=three weeks", adj = c(0, NA))

# Phthalic acid
par(fig = c(2/3,1,0,1), new = T)
offset <- 13
plot(unmilled_P[,1], scale(unmilled_P[,2]), type="l", ylim=c(-1, 34), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="c) Phthalic acid")
text(2, -1, "As received", adj = c(0, NA))
lines(t_zero_P[,1], scale(t_zero_P[,2])+offset)
text(2, 11.5, "Cryomilled: t=0", adj = c(0, NA))
lines(t_three_weeks_P[,1], scale(t_three_weeks_P[,2])+offset*2*0.9)
text(2, 22, "Cryomilled: t=three weeks", adj = c(0, NA))

dev.off()

### Bonus plots follow, not included in main paper

pdf(file="Figure_SI_1_Single_components_XRPD_peak_shifts.pdf", 8.3*0.8*2, 11.7*0.8)

### Plot main figure - SINGLE components ###

#Terephthalic acid
xmin <- 26
xmax <- 29
ymin <- -1
ymax <- 12
par(fig = c(0,1/3,0,1))
offset <- 1
plot(unmilled_T[,1], scale(unmilled_T[,2]), type="l", ylim=c(ymin, ymax), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="a) Terephthalic acid", xlim=c(xmin, xmax))
text(26.0, 0.25, "As received", adj = c(0, NA))
lines(t_zero_T[,1], scale(t_zero_T[,2])+offset, col="blue")
text(26.0, 2.25, "t=0", adj = c(0, NA))
lines(t_three_weeks_T[,1], scale(t_three_weeks_T[,2])+offset*3, col="blue")
text(26.0, 4.2, "t=3 weeks", adj = c(0, NA))

# Isophthalic acid
xmin <- 26.5
xmax <- 29
ymin <- -1
ymax <- 20
par(fig = c(1/3,2/3,0,1), new = T)
offset <- 1
plot(unmilled_I[,1], scale(unmilled_I[,2]), type="l", ylim=c(ymin,ymax), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="b) Isophthalic acid", xlim=c(xmin, xmax))
lines(t_zero_I[,1], scale(t_zero_I[,2])+offset, col="blue")
lines(t_three_weeks_I[,1], scale(t_three_weeks_I[,2])+offset*8, col="blue")

# Phthalic acid
par(fig = c(2/3,1,0,1), new = T)
xmin <- 17.5
xmax <- 19.5
ymin <- -0.5
ymax <- 6
offset <- 1
plot(unmilled_P[,1], scale(unmilled_P[,2]), type="l", ylim=c(ymin,ymax), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="c) Phthalic acid", xlim=c(xmin, xmax))
lines(t_zero_P[,1], scale(t_zero_P[,2])+offset, col="blue")
lines(t_three_weeks_P[,1], scale(t_three_weeks_P[,2])+offset*2, col="blue")

dev.off()


# Read in data

library(fields)
read_and_scale <- function(filename, xmin=5, xmax=40)
{
	tempdata <- read.csv(file=filename,  sep=" ", header=FALSE)
	tempdata <- subset(tempdata, tempdata[,1] >= xmin & tempdata[,1] <= xmax)
	tempdata[,2] <- scale(tempdata[,2])
	return(tempdata)
}

TI_together <- read_and_scale("Data/Mixtures/IT/Isophthalic and terephthalic acid CM together_zero weeks.xy")
TI_separate <- read_and_scale("Data/Mixtures/IT/Isophthalic and terephthalic acid CM separately_zero weeks.xy")
TI_together_3_weeks <- read_and_scale("Data/Mixtures/IT/Isophthalic and terephthalic acid CM together_week 3.xy")
TI_separate_3_weeks <- read_and_scale("Data/Mixtures/IT/Isophthalic and terephthalic acid CM separately_week 3.xy")

IP_together <- read_and_scale("Data/Mixtures/PI/Phthalic and isophthalic acid CM together _zero weeksxrdml.xy")
IP_separate <- read_and_scale("Data/Mixtures/PI/Phthalic and isophthalic CM separately_zero weeks.xy")
IP_together_3_weeks <- read_and_scale("Data/Mixtures/PI/Phthalic and isophthalic acid CM together_week 3.xy")
IP_separate_3_weeks <- read_and_scale("Data/Mixtures/PI/Phthalic and isophthalic acid CM separately_week 3.xy")

TP_together <- read_and_scale("Data/Mixtures/PT/Phthalic and terephthalic acid CM together_zero weeks.xy")
TP_separate <- read_and_scale("Data/Mixtures/PT/Phthalic and terephthalic acid CM separately_zero weeks.xy")
TP_together_3_weeks <- read_and_scale("Data/Mixtures/PT/Phthalic and terephthalic CM together_week3.xy")
TP_separate_3_weeks <- read_and_scale("Data/Mixtures/PT/Phthalic and terephthalic acid CM separately_week 3.xy")

par(fig = c(0,1/3,0,1))
offset <- 5 
text_height <- 2.5
plot(TI_together, type="l", ylim=c(-1, max(TI_together[,2])*2+offset*3.5+2), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="a) Terephthalic and isophthalic")
text(5, text_height, "Co-cryo-milled 0 weeks", adj = c(0, NA))
lines(TI_together_3_weeks[,1], TI_together_3_weeks[,2] + offset * 1)
text(5, text_height + offset, "Co-cryo-milled 3 weeks", adj = c(0, NA))
lines(TI_separate[,1], TI_separate[,2] + offset * 2.5)
text(5, text_height + offset*2.5, "Separately cryo-milled 0 weeks", adj = c(0, NA))
lines(TI_separate_3_weeks[,1], TI_separate_3_weeks[,2] + offset * 3.5)
text(5, text_height + offset*3.5, "Separately cryo-milled 3 weeks", adj = c(0, NA))
xline(27, col="red", lty=2)

par(fig = c(1/3,2/3,0,1), new = T)
offset <- 8
text_height <- 6
plot(IP_together, type="l", ylim=c(-1, max(IP_together[,2])*2+offset*3.5+2), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="b) Isophthalic and phthalic")
text(5, text_height-2, "Co-cryo-milled 0 weeks", adj = c(0, NA))
lines(IP_together_3_weeks[,1], IP_together_3_weeks[,2] + offset * 1)
text(5, text_height-2 + offset, "Co-cryo-milled 3 weeks", adj = c(0, NA))
lines(IP_separate[,1], IP_separate[,2] + offset * 2.5)
text(5, text_height-1 + offset*2.5, "Separately cryo-milled 0 weeks", adj = c(0, NA))
lines(IP_separate_3_weeks[,1], IP_separate_3_weeks[,2] + offset * 3.5)
text(5, text_height + offset*3.5, "Separately cryo-milled 3 weeks", adj = c(0, NA))
xline(27, col="red", lty=2)

par(fig = c(2/3,1,0,1), new = T)
offset <- 8
text_height <- 5
plot(TP_together, type="l", ylim=c(-1, max(TP_together[,2])*2+offset*3.5+2), ylab="Intensity (scaled and offset)", xlab=expression(paste("Angle (",degree,"2", theta,")")), main="c) Terephthalic and phthalic")
text(5, text_height-2, "Co-cryo-milled 0 weeks", adj = c(0, NA))
lines(TP_together_3_weeks[,1], TP_together_3_weeks[,2] + offset * 1)
text(5, text_height-2 + offset, "Co-cryo-milled 3 weeks", adj = c(0, NA))
lines(TP_separate[,1], TP_separate[,2] + offset * 2.5)
text(5, text_height-1 + offset*2.5, "Separately cryo-milled 0 weeks", adj = c(0, NA))
lines(TP_separate_3_weeks[,1], TP_separate_3_weeks[,2] + offset * 3.5)
text(5, text_height + offset*3.5, "Separately cryo-milled 3 weeks", adj = c(0, NA))
xline(27, col="red", lty=2)



q()

