##################
###Phthalic acid##
##################
library(fields)
xmin <- 680
xmax <- 1800

# function to identify carbonyl peak position
peak_position <- function(dataset, xmin=1640, xmax=1700)
{
data_for_analysis <- subset(dataset, dataset[,1] >= xmin &  dataset[,1] <= xmax)
peak_location <- data_for_analysis[which(data_for_analysis[,2] == min(data_for_analysis[,2])),1]
print(round(peak_location, digits=0))
}

pdf(file="Figure_4_FTIR_plots.pdf", 11.7, 8.3)
par(mfrow=c(2,3))

### First page - single components as a function of milling and storage time ###
terephthalic_as_received <- read.csv(file="Data/Terephthalic acid/Terephthalic acid as received.csv", skip=5, header=FALSE)
terephthalic_as_received[,2] <- scale(terephthalic_as_received[,2])
terephthalic_cryomilled_zero_weeks <- read.csv(file="Data/Terephthalic acid/Terepthalic acid cryomilled for 60mins at zero weeks.csv", skip=5, header=FALSE)
terephthalic_cryomilled_zero_weeks[,2] <- scale(terephthalic_cryomilled_zero_weeks[,2])
terephthalic_cryomilled_three_weeks <- read.csv(file="Data/Terephthalic acid/Terephthalic acid cryomilled for 60 mins after 3 weeks.csv", skip=5, header=FALSE)
terephthalic_cryomilled_three_weeks[,2] <- scale(terephthalic_cryomilled_three_weeks[,2])

isophthalic_as_received <- read.csv(file="Data/Isophthalic acid/Isophthalic acid as received.csv", skip=5, header=FALSE)
isophthalic_as_received[,2] <- scale(isophthalic_as_received[,2])
isophthalic_cryomilled_zero_weeks <- read.csv(file="Data/Isophthalic acid/Isophthalic acid_ cryomilled for 60 mins at zero weeks.csv", skip=5, header=FALSE)
isophthalic_cryomilled_zero_weeks[,2] <- scale(isophthalic_cryomilled_zero_weeks[,2])
isophthalic_cryomilled_three_weeks <- read.csv(file="Data/Isophthalic acid/Isophthalic acid cryomilled for 60 mins after 3 weeks.csv", skip=5, header=FALSE)
isophthalic_cryomilled_three_weeks[,2] <- scale(isophthalic_cryomilled_three_weeks[,2])

phthalic_as_received <- read.csv(file="Data/Phthalic acid/Phthalic acid_ as_received.csv", skip=5, header=FALSE)
phthalic_as_received[,2] <- scale(phthalic_as_received[,2])
phthalic_cryomilled_zero_weeks <- read.csv(file="Data/Phthalic acid/Phthalic acid  cryomilled for 60 mins at zero weeks.csv", skip=5, header=FALSE)
phthalic_cryomilled_zero_weeks[,2] <- scale(phthalic_cryomilled_zero_weeks[,2])
phthalic_cryomilled_three_weeks <- read.csv(file="Data/Phthalic acid/Phthalic acid cryomilled for 60 mins after 3 weeks.csv", skip=5, header=FALSE)
phthalic_cryomilled_three_weeks[,2] <- scale(phthalic_cryomilled_three_weeks[,2])

# Top left - TPA

offset <- 2
plot(terephthalic_as_received, type="l", xlab=bquote(Wavenumber~(cm^-1)), ylim=c(min(terephthalic_as_received[,2]), max(terephthalic_as_received[,2])+offset*2), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="Terephthalic acid")
lines(terephthalic_cryomilled_zero_weeks[,1], terephthalic_cryomilled_zero_weeks[,2]+offset, col="blue")
lines(terephthalic_cryomilled_three_weeks[,1], terephthalic_cryomilled_three_weeks[,2]+offset*2, col="blue")

# Top middle - IPA
plot(isophthalic_as_received, type="l", xlab=bquote(Wavenumber~(cm^-1)), ylim=c(min(isophthalic_cryomilled_zero_weeks[,2]), max(isophthalic_cryomilled_zero_weeks[,2])+offset*2), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="Isophthalic acid")
lines(isophthalic_cryomilled_zero_weeks[,1], isophthalic_cryomilled_zero_weeks[,2]+offset, col="blue")
lines(isophthalic_cryomilled_three_weeks[,1], isophthalic_cryomilled_three_weeks[,2]+offset*2, col="blue")

# Top right - PA
plot(phthalic_as_received, type="l", xlab=bquote(Wavenumber~(cm^-1)), ylim=c(min(phthalic_cryomilled_zero_weeks[,2]), max(phthalic_cryomilled_zero_weeks[,2])+offset*2), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="Phthalic acid")
lines(phthalic_cryomilled_zero_weeks[,1], phthalic_cryomilled_zero_weeks[,2]+offset, col="blue")
lines(phthalic_cryomilled_three_weeks[,1], phthalic_cryomilled_three_weeks[,2]+offset*2, col="blue")

offset <- 01
xmin <- 1640
xmax <- 1700
ymax <- 1
ymin <- min(isophthalic_cryomilled_zero_weeks[,2])

# Bottom left - TPA
plot(terephthalic_as_received, type="l", xlab=bquote(Wavenumber~(cm^-1)), ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="Terephthalic acid")
lines(terephthalic_cryomilled_zero_weeks[,1], terephthalic_cryomilled_zero_weeks[,2]+offset, col="blue")
lines(terephthalic_cryomilled_three_weeks[,1], terephthalic_cryomilled_three_weeks[,2]+offset*2, col="blue")
text(peak_position(terephthalic_as_received), -2.3, peak_position(terephthalic_as_received))
text(peak_position(terephthalic_cryomilled_zero_weeks), -1.25, peak_position(terephthalic_cryomilled_zero_weeks))
text(peak_position(terephthalic_cryomilled_three_weeks), -0.3, peak_position(terephthalic_cryomilled_three_weeks))
text(1640, -1.5, "as received", adj=c(0, 0.5))
text(1640, -0.5, "cryo-milled zero weeks", adj=c(0, 0.5), col="blue")
text(1640, 0.5, "cryo-milled three weeks", adj=c(0, 0.5), col="blue")
#Bottom middle - IPA
plot(isophthalic_as_received, type="l", xlab=bquote(Wavenumber~(cm^-1)), ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="Isophthalic acid")
lines(isophthalic_cryomilled_zero_weeks[,1], isophthalic_cryomilled_zero_weeks[,2]+offset, col="blue")
lines(isophthalic_cryomilled_three_weeks[,1], isophthalic_cryomilled_three_weeks[,2]+offset*2, col="blue")
text(peak_position(isophthalic_as_received), -2.3, peak_position(isophthalic_as_received))
text(peak_position(isophthalic_cryomilled_zero_weeks), -1.4, peak_position(isophthalic_cryomilled_zero_weeks))
text(peak_position(isophthalic_cryomilled_three_weeks), -0.5, peak_position(isophthalic_cryomilled_three_weeks))
# Bottom right - PA
plot(phthalic_as_received, type="l", xlab=bquote(Wavenumber~(cm^-1)), ylim=c(ymin,ymax), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="Phthalic acid")
lines(phthalic_cryomilled_zero_weeks[,1], phthalic_cryomilled_zero_weeks[,2]+offset, col="blue")
lines(phthalic_cryomilled_three_weeks[,1], phthalic_cryomilled_three_weeks[,2]+offset*2, col="blue")
text(peak_position(phthalic_as_received), -2.3, peak_position(phthalic_as_received))
text(peak_position(phthalic_cryomilled_zero_weeks), -1.4, peak_position(phthalic_cryomilled_zero_weeks))
text(peak_position(phthalic_cryomilled_three_weeks), -0.5, peak_position(phthalic_cryomilled_three_weeks))

dev.off()


pdf(file="Figure_2SI_FTIR_overlay_plots.pdf", 11.7, 8.3)
par(mfrow=c(1,3))
xmin <- 850
xmax <- 950

plot(terephthalic_as_received, type="l", xlab=bquote(Wavenumber~(cm^-1)), ylim=c(-2.75,-0.5), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="a) Terephthalic acid")
lines(terephthalic_cryomilled_zero_weeks[,1], terephthalic_cryomilled_zero_weeks[,2], col="blue")
lines(terephthalic_cryomilled_three_weeks[,1], terephthalic_cryomilled_three_weeks[,2]+0.6, col="blue")

plot(isophthalic_as_received, type="l", xlab=bquote(Wavenumber~(cm^-1)), ylim=c(-2.5,0.5), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="b) Isophthalic acid")
lines(isophthalic_cryomilled_zero_weeks[,1], isophthalic_cryomilled_zero_weeks[,2]+0.2, col="blue")
lines(isophthalic_cryomilled_three_weeks[,1], isophthalic_cryomilled_three_weeks[,2]+0.6, col="blue")

plot(phthalic_as_received, type="l", xlab=bquote(Wavenumber~(cm^-1)), ylim=c(-2.5,0.5), ylab="Absorbance (mean-centred, scaled, offset)", xlim=c(xmin, xmax), main="c) Phthalic acid")
lines(phthalic_cryomilled_zero_weeks[,1], phthalic_cryomilled_zero_weeks[,2]+0.2, col="blue")
lines(phthalic_cryomilled_three_weeks[,1], phthalic_cryomilled_three_weeks[,2]+0.6, col="blue")

dev.off()
