myfiles <- list.files(pattern=".csv") # <-- list all "csv" files
number.of.files <- length(myfiles) # <-- count the length of the list of files
myfiles <- myfiles[c(1,2,3)] # <-- re-arrange the order in which they are listed for a sensible plot
pdf(file="example33333.pdf") # <- Define a pdf for output, and begin writing to it
# Each plot on a separate page
par(mfrow=c(4,2)) # <- Set up a 4x2 grid and put the first 8 figures into it
for (i in 1:number.of.files) # <-- A LOOP. Type "1:number.of.files" at the R prompt to understand it.
{
	mydata <- read.csv(file=myfiles[i], skip=5, header=FALSE) # <-- Read in a csv file
	object_name <- gsub(".csv", "", myfiles[i]) # <-- This is what we will call it within R
	print(object_name) # <-- Print the object name on the screen
	assign(object_name, mydata) # <-- Assign "mydata" (read in above) to the new named object
	plot(get(object_name), type="l", main=gsub(".csv", "", gsub("_", " ", myfiles[i])), xlab="Wavenumber", ylab="Transmittance") # <-- and plot
}
par(mfrow=c(1,1)) # <-- Now revert to one plot per page
offset <- 70 # <- A variable, used in the LOOP below
for (i in 1:number.of.files) # <-- Start of loop
{
	object_name <- gsub(".csv", "", myfiles[i]) # <-- Decide what we'll work with here
	if (i == 1) # <-- Create a new plot for the first object...
	{
		        plot(get(object_name), type="l", xlab="Wavenumber", ylab="Absorbance", ylim=c(0, 80+(offset*number.of.files-1)), xlim=c(4000, 500))
	}
	if (i != 1) # <-- then add to it for remaining objects
	{
		lines(get(object_name)[,1], get(object_name)[,2]+offset*(i-1))
	}
	text(2750, 100+offset*(i-1), gsub("_", " ", object_name), cex=0.75) # <-- Add text, re-sizing via "cex" (character expansion)

}
dev.off() # <-- Close up the pdf, and write it to disk

# KEY CONCEPTS #

# Reading in structured text data. What does "skip=5" mean and why did we include it? What does "csv" stand for?
# R objects (lists, data frames, characters, integers). Use "str" or "class" to learn more
# Plots in R, including layout and x-range, y-range, main titles, etc.
# Data work-flow - remove any chances of mis-labelling plots or traces
# Substitutions via "gsub"
# Loops (for repetitive work)
# Controlling output to pdf. How might we output to a png? How might we change the size of the pdf (paper size)?
# Using the help menus via "?"
# Annotating plots, to move from data presentation to data-driven story-telling
# Commenting code via "#", so that other people can follow it. ;-)
